==> release-1.58.0.zip: documentation/content/mentorship.md <==
---
title: Mentorships
---

The Jaeger project regularly participates in mentorship programs via CNCF, such as [Outreachy](https://www.outreachy.org/), [Google Summer of Code](https://summerofcode.withgoogle.com/), and [LFX Mentorship](https://mentorship.lfx.linuxfoundation.org/). As a mentee, you will have the opportunity to contribute to an open-source project while working under the guidance of an experienced mentor who is an active contributor to the project and open-source community. The mentees receive an internship stipend.

See also:
  * [For mentees](../mentorship-for-mentees/)
  * [For mentors](../mentorship-for-mentors/)

## Google Summer of Code 2024

{{< warning >}}
* GSoC contributor application period begins March 18 - 18:00 UTC
* GSoC contributor application deadline April 2 - 18:00 UTC
{{< /warning >}}

* See [this issue](https://github.com/jaegertracing/jaeger/issues/5221) for project details.

## LFX Mentorship March-May 2024 (Term 1)

* [Harshvir Potpose](https://github.com/akagami-harsh) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [James Ryans](https://github.com/james-ryans) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [Pushkar Mishra](https://github.com/Pushkarm029) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)

## LFX Mentorship Sep-Nov 2023

* [Ansh Goyal](https://github.com/anshgoyalevil) -- [Upgrade Jaeger UI to the latest version of React.js](https://github.com/jaegertracing/jaeger-ui/issues/998)
* [Prathamesh Mutkure](https://github.com/prathamesh-mutkure) -- [Combine three distinct graph views in Jaeger UI into one](https://github.com/jaegertracing/jaeger-ui/issues/1466)
* [Yashwanth Reddy](https://github.com/pmuls99) -- [Build official support in Jaeger for Elasticsearch 8](https://github.com/jaegertracing/jaeger/issues/4600)

## LFX Mentorship Jun-Aug 2023

* [Afzal Ansari](https://github.com/afzal442) -- [Upgrade internal use of tracing to OpenTelemetry](https://github.com/jaegertracing/jaeger/issues/3381)
* [GLVS Kiriti](https://github.com/GLVSKiriti) -- [Visualize Critical Path of a trace](https://github.com/jaegertracing/jaeger-ui/issues/1288)

## Google Summer of Code 2023

* [Ha Anh Vu](https://github.com/haanhvu) -- [ClickHouse as a core storage backend](https://github.com/jaegertracing/jaeger/issues/4196)

## Outreachy Dec'20 - Mar'21

[Ashmita Bohara](https://github.com/Ashmita152)

## Outreachy Dec'18 - Mar'19

[Gaby Soria](https://github.com/gsoria)

## Outreachy May'18 - Aug'18

[Prakriti Bansal](https://github.com/PikBot)

## Outreachy Dec'17 - Mar'18

[Kara de la Marck](https://github.com/MarckK)

==> release-1.61.0.zip: documentation/content/mentorship.md <==
---
title: Mentorships
---

The Jaeger project regularly participates in mentorship programs via CNCF, such as [Outreachy](https://www.outreachy.org/), [Google Summer of Code](https://summerofcode.withgoogle.com/), and [LFX Mentorship](https://mentorship.lfx.linuxfoundation.org/). As a mentee, you will have the opportunity to contribute to an open-source project while working under the guidance of an experienced mentor who is an active contributor to the project and open-source community. The mentees receive an internship stipend.

See also:
  * [For mentees](../mentorship-for-mentees/)
  * [For mentors](../mentorship-for-mentors/)

## LFX Mentorship September-November 2024 (Term 3)

* [Ankit Kurmi](https://github.com/Ankit152) -- [Jaeger v2 Kubernetes Operator](https://github.com/jaegertracing/jaeger/issues/5766)
* [Mehul Gautam](https://github.com/hellspawn679) -- [Jaeger v2 Helm Chart](https://github.com/jaegertracing/jaeger/issues/5767)

## LFX Mentorship June-August 2024 (Term 2)

* [Harshith Mente](https://github.com/joeyyy09) -- [Jaeger-V2 Kafka-based architecture](https://github.com/jaegertracing/jaeger/issues/4868) -- [blog post](https://www.linkedin.com/posts/harshith-mente_lfxmentorship-jaeger-opentelemetry-activity-7235573030997934080-0Id1)
* [Raghuram Kannan](https://github.com/FlamingSaint) -- [Jaeger-V2 Service Performance Monitoring](https://github.com/jaegertracing/jaeger/issues/5632)
* [Saransh Shankar](https://github.com/Wise-Wizard) -- [Jaeger-V2 Observability and Health Checks](https://github.com/jaegertracing/jaeger/issues/5633) -- [blog post](https://medium.com/@saransh.shankar/my-journey-as-an-lfx-mentee-with-cncf-jaeger-b001f136ca0b)

## LFX Mentorship March-May 2024 (Term 1)

* [Harshvir Potpose](https://github.com/akagami-harsh) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [James Ryans](https://github.com/james-ryans) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)
* [Pushkar Mishra](https://github.com/Pushkarm029) -- [Jaeger V2](https://github.com/jaegertracing/jaeger/issues/5084)

## LFX Mentorship Sep-Nov 2023

* [Ansh Goyal](https://github.com/anshgoyalevil) -- [Upgrade Jaeger UI to the latest version of React.js](https://github.com/jaegertracing/jaeger-ui/issues/998)
* [Prathamesh Mutkure](https://github.com/prathamesh-mutkure) -- [Combine three distinct graph views in Jaeger UI into one](https://github.com/jaegertracing/jaeger-ui/issues/1466)
* [Yashwanth Reddy](https://github.com/pmuls99) -- [Build official support in Jaeger for Elasticsearch 8](https://github.com/jaegertracing/jaeger/issues/4600)

## LFX Mentorship Jun-Aug 2023

* [Afzal Ansari](https://github.com/afzal442) -- [Upgrade internal use of tracing to OpenTelemetry](https://github.com/jaegertracing/jaeger/issues/3381)
* [GLVS Kiriti](https://github.com/GLVSKiriti) -- [Visualize Critical Path of a trace](https://github.com/jaegertracing/jaeger-ui/issues/1288)

## Google Summer of Code 2023

* [Ha Anh Vu](https://github.com/haanhvu) -- [ClickHouse as a core storage backend](https://github.com/jaegertracing/jaeger/issues/4196) -- [blog post](https://medium.com/jaegertracing/making-design-decisions-for-clickhouse-as-a-core-storage-backend-in-jaeger-62bf90a979d)

## Outreachy Dec'20 - Mar'21

[Ashmita Bohara](https://github.com/Ashmita152)

## Outreachy Dec'18 - Mar'19

[Gaby Soria](https://github.com/gsoria)

## Outreachy May'18 - Aug'18

[Prakriti Bansal](https://github.com/PikBot)

## Outreachy Dec'17 - Mar'18

[Kara de la Marck](https://github.com/MarckK)
